@@ -1,16 +1,22 @@
 package App::p5find;
 use v5.18;
-our $VERSION = "0.04";
+use warnings;
+
+our $VERSION = "0.05";
 
 use File::Next;
 use PPI::Document::File;
 use PPIx::QuoteLike;
 
 use Exporter 'import';
-our @EXPORT_OK = qw( p5_doc_iterator
-                     p5_source_file_iterator
-                     p5_method_call_iterator
-                     print_file_linenum_line );
+our @EXPORT_OK = qw(
+                       p5_doc_iterator
+                       p5_find_iterator
+                       p5_source_file_iterator
+                       p5_method_call_iterator
+                       print_file_linenum_line
+                       iter_each
+               );
 
 my %EXCLUDED = (
     '.git' => 1,
@@ -87,6 +93,21 @@ sub p5_method_call_iterator {
     };
 }
 
+sub p5_find_iterator {
+    my ($doc, $cb) = @_;
+    my $found = $doc->find($cb) || [];
+    return sub {
+        @$found ? shift(@$found) : undef
+    }
+}
+
+sub iter_each {
+    my ($iter, $cb) = @_;
+    while (my $it = $iter->()) {
+        last unless defined $cb->($it);
+    }
+}
+
 1;
 
 __END__
